pub fn clahe_lab_rgba(
src: &[u8],
src_stride: u32,
dst: &mut [u8],
dst_stride: u32,
width: u32,
height: u32,
threshold: f32,
grid_size: ClaheGridSize,
bins_count: usize,
)Expand description
Converts image to LAB, performs CLAHE and reverts back into RGBA
Arguments
threshold- Level of clipping histogram ~[0, 10]grid_size- Grid for constructing histograms - default is (8,8)bins_count- Histogram bins, default is 128
Panics
This function panics if the lengths of the planes or the input data are not valid based on the specified width, height, and strides