Function hist_equal_lab_bgra
Source pub fn hist_equal_lab_bgra(
src: &[u8],
src_stride: u32,
dst: &mut [u8],
dst_stride: u32,
width: u32,
height: u32,
bins_count: usize,
)
Converts image to LAB, performs histogram equalization and reverts back into BGRA
Arguments
Panics
This function panics if the lengths of the planes or the input data are not valid based
on the specified width, height, and strides